@@ -9,7 +9,7 @@ Tk::GtkSettings - Give Tk applications the looks of Gtk applications
 use strict;
 use warnings;
 use File::Basename;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Exporter;
 our @ISA = qw(Exporter);
@@ -74,10 +74,6 @@ if (platformPermitted) {
 	$out_file = $ENV{HOME} . "/.tkgtksettings";
 }
 
-my $dir = dirname($0);
-print "$dir\n";
-my $file = basename($0);
-print "$file\n";
 my $no_gtk = 0;
 my %gtksettings = ();
 my %groups = (main => [[''], {}]);
@@ -177,7 +173,7 @@ Tk::GtkSettings attempts to overcome some very old complaints about Tk:
 
 Tk::GtkSettings loads your Gtk configuration files and applies it's font and color settings to your perl/Tk application.
 
-b<initDefaults> loads some nice (at least we think so) default settings that copies your Gtk theme pretty well.
+B<initDefaults> loads some nice (at least we think so) default settings that copies your Gtk theme pretty well.
 
 However, it gives plenty of tools for you to adjust it and mess it up any way you like.
 
@@ -316,7 +312,7 @@ sub convertColorCode {
 	}
 }
 
-=item B<export2file>(I<$file>, I<$removeflag>)
+=item B<export2file>(I<$file>, ?I<$removeflag>?)
 
 =over 4
 
@@ -370,7 +366,7 @@ sub export2file {
 	close XDEFO;
 }
 
-=item B<export2Xdefaults>(I<$removeflag>)
+=item B<export2Xdefaults>(?I<$removeflag>?)
 
 =over 4
 
@@ -384,7 +380,7 @@ sub export2Xdefaults {
 	export2file('~/.Xdefaults');
 }
 
-=item B<export2Xresources>(I<$removeflag>)
+=item B<export2Xresources>(?I<$removeflag>?)
 
 =over 4
 
@@ -398,7 +394,7 @@ sub export2Xresources {
 	export2file('~/.Xresources');
 }
 
-=item B<export2xrdb>(I<$removeflag>)
+=item B<export2xrdb>
 
 =over 4
 
@@ -434,7 +430,12 @@ sub generateOutput {
 	return if $no_gtk;
 	return unless platformPermitted;
 	my $output = '';
+	#group main has to be done first.
+	my (@g) = ('main');
 	for (sort keys %groups) {
+		push @g, $_ unless $_ eq 'main';
+	}
+	for (@g) {
 		my $name = $_;
 		my $group = $groups{$name};
 		my $options = $group->[1];
